# Complex Numbers

::::{grid} 1 2 2 3
:margin: 4 4 0 0
:gutter: 1

:::{grid-item-card} {octicon}`cpu` Documentation
:link: complexListing
:link-type: doc

View the API and documentation for complex numbers.
:::

:::{grid-item-card} {octicon}`tools` Examples
:link: examples
:link-type: doc

See some examples of LibRapid's complex number library in action
:::

:::{grid-item-card} {octicon}`tools` Implementation Details
:link: implementation
:link-type: doc

Learn about the implementation of complex numbers in LibRapid
:::
::::

```{toctree}
    :hidden:
    :maxdepth: 3
    
    Documentation <complexListing>
    Examples <examples>
    Implementation Details <implementation>
```
